==> kde-workspace-4.11.3.tar.xz: kde-workspace-4.11.3/kdm/kfrontend/sessions/kde-plasma-safe.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=XSession
Exec=${BIN_INSTALL_DIR}/startkde --failsafe
TryExec=${BIN_INSTALL_DIR}/startkde
Name=KDE Plasma Workspace (failsafe session)
Name[ar]=مساحة عمل بلازما كدي (الجلسة الآمنة)
Name[bn]=কে.ডি.ই. প্লাসমা ওয়ার্কস্পেস (failsafe session)
Name[bs]=KDE Plasma radni prostor (sesija otporna na padove)
Name[ca]=Espai de treball del Plasma del KDE (sessió a prova de fallades)
Name[ca@valencia]=Espai de treball del Plasma del KDE (sessió a prova de fallades)
Name[cs]=Pracovní plocha plasma (bezpečná relace)
Name[da]=KDE Plasma arbejdsområde (fejlsikker session)
Name[de]=KDE-Plasma-Arbeitsplatz (Abgesicherter Modus)
Name[el]=Χώρος εργασίας KDE Plasma (συνεδρία ασφαλούς λειτουργίας)
Name[es]=Espacio de trabajo Plasma de KDE (sesión a prueba de fallos)
Name[et]=KDE Plasma töötsoon (turvaline seanss)
Name[eu]=KDE Plasma langunea (akatsekiko saio segurua)
Name[fi]=KDE Plasma-työtila (vikasietoinen istunto)
Name[fr]=Espace de travail Plasma de KDE (session de secours)
Name[gl]=O espazo de traballo Plasma de KDE (sesión a proba de erros)
Name[he]=סביבת עבודה של KDE Plasma (הפעלה בטוחה)
Name[hr]=KDE Plasma Workspace (sigurnosna sesija)
Name[hu]=KDE Plasma munkaterület (biztonságos munkamenet)
Name[ia]=Spatio de labor de Plasma de KDE (session secur)
Name[is]=KDE Plasma-vinnurými (villuvarin seta)
Name[it]=Spazio di lavoro di KDE Plasma (sessione sicura-failsafe)
Name[kk]=KDE Plasma жұмыс орны (қауіпсіз сеанс)
Name[km]=តំបន់​ធ្វើ​ការ​ប្លាស្មា KDE (failsafe session)
Name[ko]=KDE Plasma 작업 공간 (실패 안전)
Name[lt]=KDE Plasma darbastalio erdvė (saugus seansas)
Name[lv]=KDE Plasma darba vide (kļūddrošā sesija)
Name[mr]=केडीई प्लाज्मा वर्कस्पेस (विफलता सुरक्षित सत्र)
Name[nb]=KDE Plasma arbeidsflate (sikker økt)
Name[nds]=KDE-Arbeitrebeet Plasma (Fehlerseker-Törn)
Name[nl]=KDE Plasma-werkruimte (sessie in veilige modus)
Name[pa]=ਪਲਾਜ਼ਮਾ ਡੈਸਕਟਾਪ ਵਰਕਸਪੇਸ (ਸੰਕਟਕਾਲੀਨ ਸ਼ੈਸ਼ਨ)
Name[pl]=Przestrzeń robocza Plazmy KDE (awaryjna sesja)
Name[pt]=Área de Trabalho Plasma do KDE (sessão de recurso)
Name[pt_BR]=Espaço de Trabalho Plasma do KDE (sessão segura)
Name[ro]=Spațiu de lucru Plasma KDE (sesiune robustă)
Name[ru]=Рабочий стол Plasma (безопасный режим)
Name[sk]=Pracovná plocha KDE Plasma (záchranné sedenie)
Name[sl]=Delovni prostor KDE Plasma (zasilna seja)
Name[sr]=КДЕ‑ов плазма радни простор (безотказна сесија)
Name[sr@ijekavian]=КДЕ‑ов плазма радни простор (безотказна сесија)
Name[sr@ijekavianlatin]=KDE‑ov plasma radni prostor (bezotkazna sesija)
Name[sr@latin]=KDE‑ov plasma radni prostor (bezotkazna sesija)
Name[sv]=KDE Plasma arbetsyta (felsäker session)
Name[tr]=KDE Plasma Çalışma Alanı (hatalara karşı korumalı oturum)
Name[ug]=ك د ئې(KDE) پلازما خىزمەت بوشلۇقى(بىخەتەر ئەڭگىمە)
Name[uk]=Робочий простір Плазми KDE (безпечний сеанс)
Name[vi]=Không gian Plasma KDE (phiên thử sai)
Name[x-test]=xxKDE Plasma Workspace (failsafe session)xx
Name[zh_CN]=KDE Plasma 工作空间(后备会话)
Name[zh_TW]=KDE Plasma 工作空間（救援模式）
Comment=The desktop made by KDE (failsafe session)
Comment[ar]=سطح المكتب الذي أنتجته كدي (الجلسة الآمنة)
Comment[bn]=কে.ডি.ই.-র তৈরী ডেস্কটপ (failsafe session)
Comment[bs]=Radna površina napravljena za KDE(sesija otporna na padove)
Comment[ca]=L'escriptori creat pel KDE (sessió a prova de fallades)
Comment[ca@valencia]=L'escriptori creat pel KDE (sessió a prova de fallades)
Comment[cs]=Prostředí od KDE (bezpečná relace)
Comment[da]=Skrivebordet fra KDE (fejlsikker session)
Comment[de]=Die Arbeitsfläche von KDE (Abgesicherter Modus)
Comment[el]=Η επιφάνεια εργασίας δημιουργήθηκε από το KDE (συνεδρία ασφαλούς λειτουργίας)
Comment[es]=El escritorio diseñado por KDE (sesión a prueba de fallos)
Comment[et]=KDE loodud töölaud (turvaline seanss)
Comment[eu]=KDE-k eginiko mahaigaina (akatsekiko saio segurua)
Comment[fi]=KDE:n tekemä työpöytä (vikasietoinen istunto)
Comment[fr]=Le bureau développé par KDE (session de secours)
Comment[gl]=O escritorio feito por KDE (sesión a proba de erros)
Comment[he]=שולחן העבודה של KDE (הפעלה בטוחה)
Comment[hr]=Radna površina koju je napravio KDE (sigurnosna sesija)
Comment[hu]=A KDE által készített munkaasztal (biztonságos munkamenet)
Comment[ia]=Le scriptorio facite per KDE (session secur)
Comment[is]=KDE Skjáborð (villuvarin seta)
Comment[it]=Il desktop fatto da KDE (sessione sicura-failsafe)
Comment[kk]=KDE үстелі (қаупсіз сеанс)
Comment[km]=ផ្ទៃតុ​បាន​បង្កើត​ដោយ KDE (failsafe session)
Comment[ko]=KDE에서 만든 데스크톱 (실패 안전 세션)
Comment[lt]=Darbastalis sukurtas su KDE (saugus seansas)
Comment[lv]=KDE veidota darbvirsma (kļūddrošā sesija)
Comment[mr]=केडीई ने बनवलेला डेस्कटॉप (विफलता सुरक्षित सत्र)
Comment[nb]=Skrivebordet som KDE laget (sikker økt)
Comment[nds]=KDE-Schriefdisch (Fehlerseker-Törn)
Comment[nl]=Het bureaublad gemaakt door KDE (sessie met veilig mislukken)
Comment[pa]=KDE ਵਲੋਂ ਡੈਸਕਟਾਪ (ਸੰਕਟਕਾਲੀਨ ਸ਼ੈਸ਼ਨ)
Comment[pl]=Pulpit stworzony przez KDE (awaryjna sesja)
Comment[pt]=O ambiente de trabalho feito pelo KDE (sessão de recurso)
Comment[pt_BR]=O ambiente de trabalho feito pelo KDE (sessão segura)
Comment[ro]=Biroul creat de KDE (sesiune robustă)
Comment[ru]=Окружение рабочего стола от команды KDE (безопасный режим)
Comment[sk]=Pracovná plocha od KDE (záchranné sedenie)
Comment[sl]=Namizje, ki ga je izdelal KDE (zasilna seja)
Comment[sr]=Радна површ у изведби КДЕ‑а (безотказна сесија)
Comment[sr@ijekavian]=Радна површ у изведби КДЕ‑а (безотказна сесија)
Comment[sr@ijekavianlatin]=Radna površ u izvedbi KDE‑a (bezotkazna sesija)
Comment[sr@latin]=Radna površ u izvedbi KDE‑a (bezotkazna sesija)
Comment[sv]=Skrivbordet skapat av KDE (felsäker session)
Comment[tr]=KDE tarafınndan oluşturulan masaüstü (hatalara karşı korumalı oturum)
Comment[ug]=بۇ ئۈستەلئۈستى KDE دا ياسالغان(بىخەتەر ئەڭگىمە)
Comment[uk]=Стільниця, створена командою KDE (безпечний сеанс)
Comment[x-test]=xxThe desktop made by KDE (failsafe session)xx
Comment[zh_CN]=KDE 制作的桌面(后备会话)
Comment[zh_TW]=KDE 製作的桌面（救援模式）

==> kde-workspace_4.11.8.orig.tar.xz: kde-workspace-4.11.8/kdm/kfrontend/sessions/kde-plasma-safe.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=XSession
Exec=${BIN_INSTALL_DIR}/startkde --failsafe
TryExec=${BIN_INSTALL_DIR}/startkde
Name=KDE Plasma Workspace (failsafe session)
Name[ar]=مساحة عمل بلازما كدي (الجلسة الآمنة)
Name[bn]=কে.ডি.ই. প্লাসমা ওয়ার্কস্পেস (failsafe session)
Name[bs]=KDE Plasma radni prostor (sesija otporna na padove)
Name[ca]=Espai de treball del Plasma del KDE (sessió a prova de fallades)
Name[ca@valencia]=Espai de treball del Plasma del KDE (sessió a prova de fallades)
Name[cs]=Pracovní plocha plasma (bezpečná relace)
Name[da]=KDE Plasma arbejdsområde (fejlsikker session)
Name[de]=KDE-Plasma-Arbeitsplatz (Abgesicherter Modus)
Name[el]=Χώρος εργασίας KDE Plasma (συνεδρία ασφαλούς λειτουργίας)
Name[es]=Espacio de trabajo Plasma de KDE (sesión a prueba de fallos)
Name[et]=KDE Plasma töötsoon (turvaline seanss)
Name[eu]=KDEren Plasma laneko eremua (hutsegiteetatik babestutako saioa)
Name[fi]=KDE Plasma-työtila (vikasietoinen istunto)
Name[fr]=Espace de travail Plasma de KDE (session de secours)
Name[gl]=O espazo de traballo Plasma de KDE (sesión a proba de erros)
Name[he]=סביבת עבודה של KDE Plasma (הפעלה בטוחה)
Name[hr]=KDE Plasma Workspace (sigurnosna sesija)
Name[hu]=KDE Plasma munkaterület (biztonságos munkamenet)
Name[ia]=Spatio de labor de Plasma de KDE (session secur)
Name[is]=KDE Plasma-vinnurými (villuvarin seta)
Name[it]=Spazio di lavoro di KDE Plasma (sessione sicura-failsafe)
Name[kk]=KDE Plasma жұмыс орны (қауіпсіз сеанс)
Name[km]=តំបន់​ធ្វើ​ការ​ប្លាស្មា KDE (failsafe session)
Name[ko]=KDE Plasma 작업 공간 (실패 안전)
Name[lt]=KDE Plasma darbastalio erdvė (saugus seansas)
Name[lv]=KDE Plasma darba vide (kļūddrošā sesija)
Name[mr]=केडीई प्लाज्मा वर्कस्पेस (विफलता सुरक्षित सत्र)
Name[nb]=KDE Plasma arbeidsflate (sikker økt)
Name[nds]=KDE-Arbeitrebeet Plasma (Fehlerseker-Törn)
Name[nl]=KDE Plasma-werkruimte (sessie in veilige modus)
Name[pa]=ਪਲਾਜ਼ਮਾ ਡੈਸਕਟਾਪ ਵਰਕਸਪੇਸ (ਸੰਕਟਕਾਲੀਨ ਸ਼ੈਸ਼ਨ)
Name[pl]=Przestrzeń robocza Plazmy KDE (awaryjna sesja)
Name[pt]=Área de Trabalho Plasma do KDE (sessão de recurso)
Name[pt_BR]=Espaço de Trabalho Plasma do KDE (sessão segura)
Name[ro]=Spațiu de lucru Plasma KDE (sesiune robustă)
Name[ru]=Рабочий стол Plasma (безопасный режим)
Name[sk]=Pracovná plocha KDE Plasma (záchranné sedenie)
Name[sl]=Delovni prostor KDE Plasma (zasilna seja)
Name[sr]=КДЕ‑ов плазма радни простор (безотказна сесија)
Name[sr@ijekavian]=КДЕ‑ов плазма радни простор (безотказна сесија)
Name[sr@ijekavianlatin]=KDE‑ov plasma radni prostor (bezotkazna sesija)
Name[sr@latin]=KDE‑ov plasma radni prostor (bezotkazna sesija)
Name[sv]=KDE Plasma arbetsyta (felsäker session)
Name[tr]=KDE Plasma Çalışma Alanı (hatalara karşı korumalı oturum)
Name[ug]=ك د ئې(KDE) پلازما خىزمەت بوشلۇقى(بىخەتەر ئەڭگىمە)
Name[uk]=Робочий простір Плазми KDE (безпечний сеанс)
Name[vi]=Không gian Plasma KDE (phiên thử sai)
Name[x-test]=xxKDE Plasma Workspace (failsafe session)xx
Name[zh_CN]=KDE Plasma 工作空间(后备会话)
Name[zh_TW]=KDE Plasma 工作空間（救援模式）
Comment=The desktop made by KDE (failsafe session)
Comment[ar]=سطح المكتب الذي أنتجته كدي (الجلسة الآمنة)
Comment[bn]=কে.ডি.ই.-র তৈরী ডেস্কটপ (failsafe session)
Comment[bs]=Radna površina napravljena za KDE(sesija otporna na padove)
Comment[ca]=L'escriptori creat pel KDE (sessió a prova de fallades)
Comment[ca@valencia]=L'escriptori creat pel KDE (sessió a prova de fallades)
Comment[cs]=Prostředí od KDE (bezpečná relace)
Comment[da]=Skrivebordet fra KDE (fejlsikker session)
Comment[de]=Die Arbeitsfläche von KDE (Abgesicherter Modus)
Comment[el]=Η επιφάνεια εργασίας δημιουργήθηκε από το KDE (συνεδρία ασφαλούς λειτουργίας)
Comment[es]=El escritorio diseñado por KDE (sesión a prueba de fallos)
Comment[et]=KDE loodud töölaud (turvaline seanss)
Comment[eu]=KDE-k egindako mahaigaina (hutsegiteetatik babestutako saioa)
Comment[fi]=KDE:n tekemä työpöytä (vikasietoinen istunto)
Comment[fr]=Le bureau développé par KDE (session de secours)
Comment[gl]=O escritorio feito por KDE (sesión a proba de erros)
Comment[he]=שולחן העבודה של KDE (הפעלה בטוחה)
Comment[hr]=Radna površina koju je napravio KDE (sigurnosna sesija)
Comment[hu]=A KDE által készített munkaasztal (biztonságos munkamenet)
Comment[ia]=Le scriptorio facite per KDE (session secur)
Comment[is]=KDE Skjáborð (villuvarin seta)
Comment[it]=Il desktop fatto da KDE (sessione sicura-failsafe)
Comment[kk]=KDE үстелі (қаупсіз сеанс)
Comment[km]=ផ្ទៃតុ​បាន​បង្កើត​ដោយ KDE (failsafe session)
Comment[ko]=KDE에서 만든 데스크톱 (실패 안전 세션)
Comment[lt]=Darbastalis sukurtas su KDE (saugus seansas)
Comment[lv]=KDE veidota darbvirsma (kļūddrošā sesija)
Comment[mr]=केडीई ने बनवलेला डेस्कटॉप (विफलता सुरक्षित सत्र)
Comment[nb]=Skrivebordet som KDE laget (sikker økt)
Comment[nds]=KDE-Schriefdisch (Fehlerseker-Törn)
Comment[nl]=Het bureaublad gemaakt door KDE (sessie met veilig mislukken)
Comment[pa]=KDE ਵਲੋਂ ਡੈਸਕਟਾਪ (ਸੰਕਟਕਾਲੀਨ ਸ਼ੈਸ਼ਨ)
Comment[pl]=Pulpit stworzony przez KDE (awaryjna sesja)
Comment[pt]=O ambiente de trabalho feito pelo KDE (sessão de recurso)
Comment[pt_BR]=O ambiente de trabalho feito pelo KDE (sessão segura)
Comment[ro]=Biroul creat de KDE (sesiune robustă)
Comment[ru]=Окружение рабочего стола от команды KDE (безопасный режим)
Comment[sk]=Pracovná plocha od KDE (záchranné sedenie)
Comment[sl]=Namizje, ki ga je izdelal KDE (zasilna seja)
Comment[sr]=Радна површ у изведби КДЕ‑а (безотказна сесија)
Comment[sr@ijekavian]=Радна површ у изведби КДЕ‑а (безотказна сесија)
Comment[sr@ijekavianlatin]=Radna površ u izvedbi KDE‑a (bezotkazna sesija)
Comment[sr@latin]=Radna površ u izvedbi KDE‑a (bezotkazna sesija)
Comment[sv]=Skrivbordet skapat av KDE (felsäker session)
Comment[tr]=KDE tarafınndan oluşturulan masaüstü (hatalara karşı korumalı oturum)
Comment[ug]=بۇ ئۈستەلئۈستى KDE دا ياسالغان(بىخەتەر ئەڭگىمە)
Comment[uk]=Стільниця, створена командою KDE (безпечний сеанс)
Comment[x-test]=xxThe desktop made by KDE (failsafe session)xx
Comment[zh_CN]=KDE 制作的桌面(后备会话)
Comment[zh_TW]=KDE 製作的桌面（救援模式）
